@@ -18,7 +18,7 @@ import base64
 import copy
 import six
 
-from google.cloud.datastore_v1.proto import entity_pb2 as _entity_pb2
+from google.cloud.datastore_v1.types import entity as _entity_pb2
 
 from google.cloud._helpers import _to_bytes
 from google.cloud.datastore import _app_engine_key_pb2
@@ -289,14 +289,14 @@ class Key(object):
             key.partition_id.namespace_id = self.namespace
 
         for item in self.path:
-            element = key.path.add()
+            element = key.PathElement()
             if "kind" in item:
                 element.kind = item["kind"]
             if "id" in item:
                 element.id = item["id"]
             if "name" in item:
                 element.name = item["name"]
-
+            key.path.append(element)
         return key
 
     def to_legacy_urlsafe(self, location_prefix=None):
@@ -441,7 +441,9 @@ class Key(object):
         :returns: The last element of the key's path if it is either an ``id``
                   or a ``name``.
         """
-        return self.id or self.name
+        if self.id is None:
+            return self.name
+        return self.id
 
     @property
     def project(self):
