@@ -90,7 +90,7 @@ class Test__rpc(unittest.TestCase):
         return _rpc(*args, **kwargs)
 
     def test_it(self):
-        from google.cloud.datastore_v1.proto import datastore_pb2
+        from google.cloud.datastore_v1.types import datastore as datastore_pb2
 
         http = object()
         project = "projectOK"
@@ -102,7 +102,7 @@ class Test__rpc(unittest.TestCase):
         response_pb = datastore_pb2.BeginTransactionResponse(transaction=b"7830rmc")
         patch = mock.patch(
             "google.cloud.datastore._http._request",
-            return_value=response_pb.SerializeToString(),
+            return_value=response_pb._pb.SerializeToString(),
         )
         with patch as mock_request:
             result = self._call_fut(
@@ -114,13 +114,13 @@ class Test__rpc(unittest.TestCase):
                 request_pb,
                 datastore_pb2.BeginTransactionResponse,
             )
-            self.assertEqual(result, response_pb)
+            self.assertEqual(result, response_pb._pb)
 
             mock_request.assert_called_once_with(
                 http,
                 project,
                 method,
-                request_pb.SerializeToString(),
+                request_pb._pb.SerializeToString(),
                 base_url,
                 client_info,
             )
@@ -138,7 +138,7 @@ class TestHTTPDatastoreAPI(unittest.TestCase):
 
     @staticmethod
     def _make_query_pb(kind):
-        from google.cloud.datastore_v1.proto import query_pb2
+        from google.cloud.datastore_v1.types import query as query_pb2
 
         return query_pb2.Query(kind=[query_pb2.KindExpression(name=kind)])
 
@@ -148,7 +148,7 @@ class TestHTTPDatastoreAPI(unittest.TestCase):
         self.assertIs(ds_api.client, client)
 
     def test_lookup_single_key_empty_response(self):
-        from google.cloud.datastore_v1.proto import datastore_pb2
+        from google.cloud.datastore_v1.types import datastore as datastore_pb2
 
         project = "PROJECT"
         key_pb = _make_key_pb(project)
@@ -157,7 +157,7 @@ class TestHTTPDatastoreAPI(unittest.TestCase):
 
         # Create mock HTTP and client with response.
         http = _make_requests_session(
-            [_make_response(content=rsp_pb.SerializeToString())]
+            [_make_response(content=rsp_pb._pb.SerializeToString())]
         )
         client_info = _make_client_info()
         client = mock.Mock(
@@ -172,29 +172,29 @@ class TestHTTPDatastoreAPI(unittest.TestCase):
         response = ds_api.lookup(project, [key_pb], read_options=read_options)
 
         # Check the result and verify the callers.
-        self.assertEqual(response, rsp_pb)
+        self.assertEqual(response, rsp_pb._pb)
         uri = _build_expected_url(client._base_url, project, "lookup")
         self.assertEqual(len(response.found), 0)
         self.assertEqual(len(response.missing), 0)
         self.assertEqual(len(response.deferred), 0)
 
         request = _verify_protobuf_call(http, uri, datastore_pb2.LookupRequest())
-        self.assertEqual(list(request.keys), [key_pb])
-        self.assertEqual(request.read_options, read_options)
+        self.assertEqual(list(request.keys), [key_pb._pb])
+        self.assertEqual(request.read_options, read_options._pb)
 
     def test_lookup_single_key_empty_response_w_eventual(self):
-        from google.cloud.datastore_v1.proto import datastore_pb2
+        from google.cloud.datastore_v1.types import datastore as datastore_pb2
 
         project = "PROJECT"
         key_pb = _make_key_pb(project)
         rsp_pb = datastore_pb2.LookupResponse()
         read_options = datastore_pb2.ReadOptions(
-            read_consistency=datastore_pb2.ReadOptions.EVENTUAL
+            read_consistency=datastore_pb2.ReadOptions.ReadConsistency.EVENTUAL
         )
 
         # Create mock HTTP and client with response.
         http = _make_requests_session(
-            [_make_response(content=rsp_pb.SerializeToString())]
+            [_make_response(content=rsp_pb._pb.SerializeToString())]
         )
         client_info = _make_client_info()
         client = mock.Mock(
@@ -209,18 +209,18 @@ class TestHTTPDatastoreAPI(unittest.TestCase):
         response = ds_api.lookup(project, [key_pb], read_options=read_options)
 
         # Check the result and verify the callers.
-        self.assertEqual(response, rsp_pb)
+        self.assertEqual(response, rsp_pb._pb)
         uri = _build_expected_url(client._base_url, project, "lookup")
         self.assertEqual(len(response.found), 0)
         self.assertEqual(len(response.missing), 0)
         self.assertEqual(len(response.deferred), 0)
 
         request = _verify_protobuf_call(http, uri, datastore_pb2.LookupRequest())
-        self.assertEqual(list(request.keys), [key_pb])
-        self.assertEqual(request.read_options, read_options)
+        self.assertEqual(list(request.keys), [key_pb._pb])
+        self.assertEqual(request.read_options, read_options._pb)
 
     def test_lookup_single_key_empty_response_w_transaction(self):
-        from google.cloud.datastore_v1.proto import datastore_pb2
+        from google.cloud.datastore_v1.types import datastore as datastore_pb2
 
         project = "PROJECT"
         transaction = b"TRANSACTION"
@@ -230,7 +230,7 @@ class TestHTTPDatastoreAPI(unittest.TestCase):
 
         # Create mock HTTP and client with response.
         http = _make_requests_session(
-            [_make_response(content=rsp_pb.SerializeToString())]
+            [_make_response(content=rsp_pb._pb.SerializeToString())]
         )
         client_info = _make_client_info()
         client = mock.Mock(
@@ -245,31 +245,31 @@ class TestHTTPDatastoreAPI(unittest.TestCase):
         response = ds_api.lookup(project, [key_pb], read_options=read_options)
 
         # Check the result and verify the callers.
-        self.assertEqual(response, rsp_pb)
+        self.assertEqual(response, rsp_pb._pb)
         uri = _build_expected_url(client._base_url, project, "lookup")
         self.assertEqual(len(response.found), 0)
         self.assertEqual(len(response.missing), 0)
         self.assertEqual(len(response.deferred), 0)
 
         request = _verify_protobuf_call(http, uri, datastore_pb2.LookupRequest())
-        self.assertEqual(list(request.keys), [key_pb])
-        self.assertEqual(request.read_options, read_options)
+        self.assertEqual(list(request.keys), [key_pb._pb])
+        self.assertEqual(request.read_options, read_options._pb)
 
     def test_lookup_single_key_nonempty_response(self):
-        from google.cloud.datastore_v1.proto import datastore_pb2
-        from google.cloud.datastore_v1.proto import entity_pb2
+        from google.cloud.datastore_v1.types import datastore as datastore_pb2
+        from google.cloud.datastore_v1.types import entity as entity_pb2
 
         project = "PROJECT"
         key_pb = _make_key_pb(project)
         rsp_pb = datastore_pb2.LookupResponse()
         entity = entity_pb2.Entity()
-        entity.key.CopyFrom(key_pb)
-        rsp_pb.found.add(entity=entity)
+        entity.key._pb.CopyFrom(key_pb._pb)
+        rsp_pb._pb.found.add(entity=entity._pb)
         read_options = datastore_pb2.ReadOptions()
 
         # Create mock HTTP and client with response.
         http = _make_requests_session(
-            [_make_response(content=rsp_pb.SerializeToString())]
+            [_make_response(content=rsp_pb._pb.SerializeToString())]
         )
         client_info = _make_client_info()
         client = mock.Mock(
@@ -284,7 +284,7 @@ class TestHTTPDatastoreAPI(unittest.TestCase):
         response = ds_api.lookup(project, [key_pb], read_options=read_options)
 
         # Check the result and verify the callers.
-        self.assertEqual(response, rsp_pb)
+        self.assertEqual(response, rsp_pb._pb)
         uri = _build_expected_url(client._base_url, project, "lookup")
         self.assertEqual(len(response.found), 1)
         self.assertEqual(len(response.missing), 0)
@@ -294,11 +294,11 @@ class TestHTTPDatastoreAPI(unittest.TestCase):
         self.assertEqual(found.key.path[0].id, 1234)
 
         request = _verify_protobuf_call(http, uri, datastore_pb2.LookupRequest())
-        self.assertEqual(list(request.keys), [key_pb])
-        self.assertEqual(request.read_options, read_options)
+        self.assertEqual(list(request.keys), [key_pb._pb])
+        self.assertEqual(request.read_options, read_options._pb)
 
     def test_lookup_multiple_keys_empty_response(self):
-        from google.cloud.datastore_v1.proto import datastore_pb2
+        from google.cloud.datastore_v1.types import datastore as datastore_pb2
 
         project = "PROJECT"
         key_pb1 = _make_key_pb(project)
@@ -308,7 +308,7 @@ class TestHTTPDatastoreAPI(unittest.TestCase):
 
         # Create mock HTTP and client with response.
         http = _make_requests_session(
-            [_make_response(content=rsp_pb.SerializeToString())]
+            [_make_response(content=rsp_pb._pb.SerializeToString())]
         )
         client_info = _make_client_info()
         client = mock.Mock(
@@ -323,32 +323,32 @@ class TestHTTPDatastoreAPI(unittest.TestCase):
         response = ds_api.lookup(project, [key_pb1, key_pb2], read_options=read_options)
 
         # Check the result and verify the callers.
-        self.assertEqual(response, rsp_pb)
+        self.assertEqual(response, rsp_pb._pb)
         uri = _build_expected_url(client._base_url, project, "lookup")
         self.assertEqual(len(response.found), 0)
         self.assertEqual(len(response.missing), 0)
         self.assertEqual(len(response.deferred), 0)
 
         request = _verify_protobuf_call(http, uri, datastore_pb2.LookupRequest())
-        self.assertEqual(list(request.keys), [key_pb1, key_pb2])
-        self.assertEqual(request.read_options, read_options)
+        self.assertEqual(list(request.keys), [key_pb1._pb, key_pb2._pb])
+        self.assertEqual(request.read_options, read_options._pb)
 
     def test_lookup_multiple_keys_w_missing(self):
-        from google.cloud.datastore_v1.proto import datastore_pb2
+        from google.cloud.datastore_v1.types import datastore as datastore_pb2
 
         project = "PROJECT"
         key_pb1 = _make_key_pb(project)
         key_pb2 = _make_key_pb(project, id_=2345)
         rsp_pb = datastore_pb2.LookupResponse()
-        er_1 = rsp_pb.missing.add()
-        er_1.entity.key.CopyFrom(key_pb1)
-        er_2 = rsp_pb.missing.add()
-        er_2.entity.key.CopyFrom(key_pb2)
+        er_1 = rsp_pb._pb.missing.add()
+        er_1.entity.key.CopyFrom(key_pb1._pb)
+        er_2 = rsp_pb._pb.missing.add()
+        er_2.entity.key.CopyFrom(key_pb2._pb)
         read_options = datastore_pb2.ReadOptions()
 
         # Create mock HTTP and client with response.
         http = _make_requests_session(
-            [_make_response(content=rsp_pb.SerializeToString())]
+            [_make_response(content=rsp_pb._pb.SerializeToString())]
         )
         client_info = _make_client_info()
         client = mock.Mock(
@@ -363,31 +363,31 @@ class TestHTTPDatastoreAPI(unittest.TestCase):
         response = ds_api.lookup(project, [key_pb1, key_pb2], read_options=read_options)
 
         # Check the result and verify the callers.
-        self.assertEqual(response, rsp_pb)
+        self.assertEqual(response, rsp_pb._pb)
         uri = _build_expected_url(client._base_url, project, "lookup")
         self.assertEqual(len(response.found), 0)
         self.assertEqual(len(response.deferred), 0)
         missing_keys = [result.entity.key for result in response.missing]
-        self.assertEqual(missing_keys, [key_pb1, key_pb2])
+        self.assertEqual(missing_keys, [key_pb1._pb, key_pb2._pb])
 
         request = _verify_protobuf_call(http, uri, datastore_pb2.LookupRequest())
-        self.assertEqual(list(request.keys), [key_pb1, key_pb2])
-        self.assertEqual(request.read_options, read_options)
+        self.assertEqual(list(request.keys), [key_pb1._pb, key_pb2._pb])
+        self.assertEqual(request.read_options, read_options._pb)
 
     def test_lookup_multiple_keys_w_deferred(self):
-        from google.cloud.datastore_v1.proto import datastore_pb2
+        from google.cloud.datastore_v1.types import datastore as datastore_pb2
 
         project = "PROJECT"
         key_pb1 = _make_key_pb(project)
         key_pb2 = _make_key_pb(project, id_=2345)
         rsp_pb = datastore_pb2.LookupResponse()
-        rsp_pb.deferred.add().CopyFrom(key_pb1)
-        rsp_pb.deferred.add().CopyFrom(key_pb2)
+        rsp_pb._pb.deferred.add().CopyFrom(key_pb1._pb)
+        rsp_pb._pb.deferred.add().CopyFrom(key_pb2._pb)
         read_options = datastore_pb2.ReadOptions()
 
         # Create mock HTTP and client with response.
         http = _make_requests_session(
-            [_make_response(content=rsp_pb.SerializeToString())]
+            [_make_response(content=rsp_pb._pb.SerializeToString())]
         )
         client_info = _make_client_info()
         client = mock.Mock(
@@ -402,20 +402,20 @@ class TestHTTPDatastoreAPI(unittest.TestCase):
         response = ds_api.lookup(project, [key_pb1, key_pb2], read_options=read_options)
 
         # Check the result and verify the callers.
-        self.assertEqual(response, rsp_pb)
+        self.assertEqual(response, rsp_pb._pb)
         uri = _build_expected_url(client._base_url, project, "lookup")
         self.assertEqual(len(response.found), 0)
         self.assertEqual(len(response.missing), 0)
-        self.assertEqual(list(response.deferred), [key_pb1, key_pb2])
+        self.assertEqual(list(response.deferred), [key_pb1._pb, key_pb2._pb])
 
         request = _verify_protobuf_call(http, uri, datastore_pb2.LookupRequest())
-        self.assertEqual(list(request.keys), [key_pb1, key_pb2])
-        self.assertEqual(request.read_options, read_options)
+        self.assertEqual(list(request.keys), [key_pb1._pb, key_pb2._pb])
+        self.assertEqual(request.read_options, read_options._pb)
 
     def test_run_query_w_eventual_no_transaction(self):
-        from google.cloud.datastore_v1.proto import datastore_pb2
-        from google.cloud.datastore_v1.proto import entity_pb2
-        from google.cloud.datastore_v1.proto import query_pb2
+        from google.cloud.datastore_v1.types import datastore as datastore_pb2
+        from google.cloud.datastore_v1.types import entity as entity_pb2
+        from google.cloud.datastore_v1.types import query as query_pb2
 
         project = "PROJECT"
         kind = "Nonesuch"
@@ -423,19 +423,19 @@ class TestHTTPDatastoreAPI(unittest.TestCase):
         query_pb = self._make_query_pb(kind)
         partition_id = entity_pb2.PartitionId(project_id=project)
         read_options = datastore_pb2.ReadOptions(
-            read_consistency=datastore_pb2.ReadOptions.EVENTUAL
+            read_consistency=datastore_pb2.ReadOptions.ReadConsistency.EVENTUAL
         )
         rsp_pb = datastore_pb2.RunQueryResponse(
             batch=query_pb2.QueryResultBatch(
-                entity_result_type=query_pb2.EntityResult.FULL,
+                entity_result_type=query_pb2.EntityResult.ResultType.FULL,
                 end_cursor=cursor,
-                more_results=query_pb2.QueryResultBatch.NO_MORE_RESULTS,
+                more_results=query_pb2.QueryResultBatch.MoreResultsType.NO_MORE_RESULTS,
             )
         )
 
         # Create mock HTTP and client with response.
         http = _make_requests_session(
-            [_make_response(content=rsp_pb.SerializeToString())]
+            [_make_response(content=rsp_pb._pb.SerializeToString())]
         )
         client_info = _make_client_info()
         client = mock.Mock(
@@ -450,18 +450,18 @@ class TestHTTPDatastoreAPI(unittest.TestCase):
         response = ds_api.run_query(project, partition_id, read_options, query=query_pb)
 
         # Check the result and verify the callers.
-        self.assertEqual(response, rsp_pb)
+        self.assertEqual(response, rsp_pb._pb)
 
         uri = _build_expected_url(client._base_url, project, "runQuery")
         request = _verify_protobuf_call(http, uri, datastore_pb2.RunQueryRequest())
-        self.assertEqual(request.partition_id, partition_id)
-        self.assertEqual(request.query, query_pb)
-        self.assertEqual(request.read_options, read_options)
+        self.assertEqual(request.partition_id, partition_id._pb)
+        self.assertEqual(request.query, query_pb._pb)
+        self.assertEqual(request.read_options, read_options._pb)
 
     def test_run_query_wo_eventual_w_transaction(self):
-        from google.cloud.datastore_v1.proto import datastore_pb2
-        from google.cloud.datastore_v1.proto import entity_pb2
-        from google.cloud.datastore_v1.proto import query_pb2
+        from google.cloud.datastore_v1.types import datastore as datastore_pb2
+        from google.cloud.datastore_v1.types import entity as entity_pb2
+        from google.cloud.datastore_v1.types import query as query_pb2
 
         project = "PROJECT"
         kind = "Nonesuch"
@@ -472,15 +472,15 @@ class TestHTTPDatastoreAPI(unittest.TestCase):
         read_options = datastore_pb2.ReadOptions(transaction=transaction)
         rsp_pb = datastore_pb2.RunQueryResponse(
             batch=query_pb2.QueryResultBatch(
-                entity_result_type=query_pb2.EntityResult.FULL,
+                entity_result_type=query_pb2.EntityResult.ResultType.FULL,
                 end_cursor=cursor,
-                more_results=query_pb2.QueryResultBatch.NO_MORE_RESULTS,
+                more_results=query_pb2.QueryResultBatch.MoreResultsType.NO_MORE_RESULTS,
             )
         )
 
         # Create mock HTTP and client with response.
         http = _make_requests_session(
-            [_make_response(content=rsp_pb.SerializeToString())]
+            [_make_response(content=rsp_pb._pb.SerializeToString())]
         )
         client_info = _make_client_info()
         client = mock.Mock(
@@ -495,18 +495,18 @@ class TestHTTPDatastoreAPI(unittest.TestCase):
         response = ds_api.run_query(project, partition_id, read_options, query=query_pb)
 
         # Check the result and verify the callers.
-        self.assertEqual(response, rsp_pb)
+        self.assertEqual(response, rsp_pb._pb)
 
         uri = _build_expected_url(client._base_url, project, "runQuery")
         request = _verify_protobuf_call(http, uri, datastore_pb2.RunQueryRequest())
-        self.assertEqual(request.partition_id, partition_id)
-        self.assertEqual(request.query, query_pb)
-        self.assertEqual(request.read_options, read_options)
+        self.assertEqual(request.partition_id, partition_id._pb)
+        self.assertEqual(request.query, query_pb._pb)
+        self.assertEqual(request.read_options, read_options._pb)
 
     def test_run_query_wo_namespace_empty_result(self):
-        from google.cloud.datastore_v1.proto import datastore_pb2
-        from google.cloud.datastore_v1.proto import entity_pb2
-        from google.cloud.datastore_v1.proto import query_pb2
+        from google.cloud.datastore_v1.types import datastore as datastore_pb2
+        from google.cloud.datastore_v1.types import entity as entity_pb2
+        from google.cloud.datastore_v1.types import query as query_pb2
 
         project = "PROJECT"
         kind = "Nonesuch"
@@ -516,15 +516,15 @@ class TestHTTPDatastoreAPI(unittest.TestCase):
         read_options = datastore_pb2.ReadOptions()
         rsp_pb = datastore_pb2.RunQueryResponse(
             batch=query_pb2.QueryResultBatch(
-                entity_result_type=query_pb2.EntityResult.FULL,
+                entity_result_type=query_pb2.EntityResult.ResultType.FULL,
                 end_cursor=cursor,
-                more_results=query_pb2.QueryResultBatch.NO_MORE_RESULTS,
+                more_results=query_pb2.QueryResultBatch.MoreResultsType.NO_MORE_RESULTS,
             )
         )
 
         # Create mock HTTP and client with response.
         http = _make_requests_session(
-            [_make_response(content=rsp_pb.SerializeToString())]
+            [_make_response(content=rsp_pb._pb.SerializeToString())]
         )
         client_info = _make_client_info()
         client = mock.Mock(
@@ -539,18 +539,18 @@ class TestHTTPDatastoreAPI(unittest.TestCase):
         response = ds_api.run_query(project, partition_id, read_options, query=query_pb)
 
         # Check the result and verify the callers.
-        self.assertEqual(response, rsp_pb)
+        self.assertEqual(response, rsp_pb._pb)
 
         uri = _build_expected_url(client._base_url, project, "runQuery")
         request = _verify_protobuf_call(http, uri, datastore_pb2.RunQueryRequest())
-        self.assertEqual(request.partition_id, partition_id)
-        self.assertEqual(request.query, query_pb)
-        self.assertEqual(request.read_options, read_options)
+        self.assertEqual(request.partition_id, partition_id._pb)
+        self.assertEqual(request.query, query_pb._pb)
+        self.assertEqual(request.read_options, read_options._pb)
 
     def test_run_query_w_namespace_nonempty_result(self):
-        from google.cloud.datastore_v1.proto import datastore_pb2
-        from google.cloud.datastore_v1.proto import entity_pb2
-        from google.cloud.datastore_v1.proto import query_pb2
+        from google.cloud.datastore_v1.types import datastore as datastore_pb2
+        from google.cloud.datastore_v1.types import entity as entity_pb2
+        from google.cloud.datastore_v1.types import query as query_pb2
 
         project = "PROJECT"
         kind = "Kind"
@@ -562,15 +562,15 @@ class TestHTTPDatastoreAPI(unittest.TestCase):
         read_options = datastore_pb2.ReadOptions()
         rsp_pb = datastore_pb2.RunQueryResponse(
             batch=query_pb2.QueryResultBatch(
-                entity_result_type=query_pb2.EntityResult.FULL,
+                entity_result_type=query_pb2.EntityResult.ResultType.FULL,
                 entity_results=[query_pb2.EntityResult(entity=entity_pb2.Entity())],
-                more_results=query_pb2.QueryResultBatch.NO_MORE_RESULTS,
+                more_results=query_pb2.QueryResultBatch.MoreResultsType.NO_MORE_RESULTS,
             )
         )
 
         # Create mock HTTP and client with response.
         http = _make_requests_session(
-            [_make_response(content=rsp_pb.SerializeToString())]
+            [_make_response(content=rsp_pb._pb.SerializeToString())]
         )
         client_info = _make_client_info()
         client = mock.Mock(
@@ -585,15 +585,15 @@ class TestHTTPDatastoreAPI(unittest.TestCase):
         response = ds_api.run_query(project, partition_id, read_options, query=query_pb)
 
         # Check the result and verify the callers.
-        self.assertEqual(response, rsp_pb)
+        self.assertEqual(response, rsp_pb._pb)
 
         uri = _build_expected_url(client._base_url, project, "runQuery")
         request = _verify_protobuf_call(http, uri, datastore_pb2.RunQueryRequest())
-        self.assertEqual(request.partition_id, partition_id)
-        self.assertEqual(request.query, query_pb)
+        self.assertEqual(request.partition_id, partition_id._pb)
+        self.assertEqual(request.query, query_pb._pb)
 
     def test_begin_transaction(self):
-        from google.cloud.datastore_v1.proto import datastore_pb2
+        from google.cloud.datastore_v1.types import datastore as datastore_pb2
 
         project = "PROJECT"
         transaction = b"TRANSACTION"
@@ -602,7 +602,7 @@ class TestHTTPDatastoreAPI(unittest.TestCase):
 
         # Create mock HTTP and client with response.
         http = _make_requests_session(
-            [_make_response(content=rsp_pb.SerializeToString())]
+            [_make_response(content=rsp_pb._pb.SerializeToString())]
         )
         client_info = _make_client_info()
         client = mock.Mock(
@@ -617,7 +617,7 @@ class TestHTTPDatastoreAPI(unittest.TestCase):
         response = ds_api.begin_transaction(project)
 
         # Check the result and verify the callers.
-        self.assertEqual(response, rsp_pb)
+        self.assertEqual(response, rsp_pb._pb)
 
         uri = _build_expected_url(client._base_url, project, "beginTransaction")
         request = _verify_protobuf_call(
@@ -627,22 +627,22 @@ class TestHTTPDatastoreAPI(unittest.TestCase):
         self.assertEqual(request.project_id, u"")
 
     def test_commit_wo_transaction(self):
-        from google.cloud.datastore_v1.proto import datastore_pb2
+        from google.cloud.datastore_v1.types import datastore as datastore_pb2
         from google.cloud.datastore.helpers import _new_value_pb
 
         project = "PROJECT"
         key_pb = _make_key_pb(project)
         rsp_pb = datastore_pb2.CommitResponse()
         req_pb = datastore_pb2.CommitRequest()
-        mutation = req_pb.mutations.add()
+        mutation = req_pb._pb.mutations.add()
         insert = mutation.upsert
-        insert.key.CopyFrom(key_pb)
+        insert.key.CopyFrom(key_pb._pb)
         value_pb = _new_value_pb(insert, "foo")
         value_pb.string_value = u"Foo"
 
         # Create mock HTTP and client with response.
         http = _make_requests_session(
-            [_make_response(content=rsp_pb.SerializeToString())]
+            [_make_response(content=rsp_pb._pb.SerializeToString())]
         )
         client_info = _make_client_info()
         client = mock.Mock(
@@ -655,35 +655,35 @@ class TestHTTPDatastoreAPI(unittest.TestCase):
         # Make request.
         rq_class = datastore_pb2.CommitRequest
         ds_api = self._make_one(client)
-        mode = rq_class.NON_TRANSACTIONAL
+        mode = rq_class.Mode.NON_TRANSACTIONAL
         result = ds_api.commit(project, mode, [mutation])
 
         # Check the result and verify the callers.
-        self.assertEqual(result, rsp_pb)
+        self.assertEqual(result, rsp_pb._pb)
 
         uri = _build_expected_url(client._base_url, project, "commit")
         request = _verify_protobuf_call(http, uri, rq_class())
         self.assertEqual(request.transaction, b"")
         self.assertEqual(list(request.mutations), [mutation])
-        self.assertEqual(request.mode, rq_class.NON_TRANSACTIONAL)
+        self.assertEqual(request.mode, rq_class.Mode.NON_TRANSACTIONAL)
 
     def test_commit_w_transaction(self):
-        from google.cloud.datastore_v1.proto import datastore_pb2
+        from google.cloud.datastore_v1.types import datastore as datastore_pb2
         from google.cloud.datastore.helpers import _new_value_pb
 
         project = "PROJECT"
         key_pb = _make_key_pb(project)
         rsp_pb = datastore_pb2.CommitResponse()
         req_pb = datastore_pb2.CommitRequest()
-        mutation = req_pb.mutations.add()
+        mutation = req_pb._pb.mutations.add()
         insert = mutation.upsert
-        insert.key.CopyFrom(key_pb)
+        insert.key.CopyFrom(key_pb._pb)
         value_pb = _new_value_pb(insert, "foo")
         value_pb.string_value = u"Foo"
 
         # Create mock HTTP and client with response.
         http = _make_requests_session(
-            [_make_response(content=rsp_pb.SerializeToString())]
+            [_make_response(content=rsp_pb._pb.SerializeToString())]
         )
         client_info = _make_client_info()
         client = mock.Mock(
@@ -696,20 +696,20 @@ class TestHTTPDatastoreAPI(unittest.TestCase):
         # Make request.
         rq_class = datastore_pb2.CommitRequest
         ds_api = self._make_one(client)
-        mode = rq_class.TRANSACTIONAL
+        mode = rq_class.Mode.TRANSACTIONAL
         result = ds_api.commit(project, mode, [mutation], transaction=b"xact")
 
         # Check the result and verify the callers.
-        self.assertEqual(result, rsp_pb)
+        self.assertEqual(result, rsp_pb._pb)
 
         uri = _build_expected_url(client._base_url, project, "commit")
         request = _verify_protobuf_call(http, uri, rq_class())
         self.assertEqual(request.transaction, b"xact")
         self.assertEqual(list(request.mutations), [mutation])
-        self.assertEqual(request.mode, rq_class.TRANSACTIONAL)
+        self.assertEqual(request.mode, rq_class.Mode.TRANSACTIONAL)
 
     def test_rollback_ok(self):
-        from google.cloud.datastore_v1.proto import datastore_pb2
+        from google.cloud.datastore_v1.types import datastore as datastore_pb2
 
         project = "PROJECT"
         transaction = b"xact"
@@ -717,7 +717,7 @@ class TestHTTPDatastoreAPI(unittest.TestCase):
 
         # Create mock HTTP and client with response.
         http = _make_requests_session(
-            [_make_response(content=rsp_pb.SerializeToString())]
+            [_make_response(content=rsp_pb._pb.SerializeToString())]
         )
         client_info = _make_client_info()
         client = mock.Mock(
@@ -732,21 +732,21 @@ class TestHTTPDatastoreAPI(unittest.TestCase):
         response = ds_api.rollback(project, transaction)
 
         # Check the result and verify the callers.
-        self.assertEqual(response, rsp_pb)
+        self.assertEqual(response, rsp_pb._pb)
 
         uri = _build_expected_url(client._base_url, project, "rollback")
         request = _verify_protobuf_call(http, uri, datastore_pb2.RollbackRequest())
         self.assertEqual(request.transaction, transaction)
 
     def test_allocate_ids_empty(self):
-        from google.cloud.datastore_v1.proto import datastore_pb2
+        from google.cloud.datastore_v1.types import datastore as datastore_pb2
 
         project = "PROJECT"
         rsp_pb = datastore_pb2.AllocateIdsResponse()
 
         # Create mock HTTP and client with response.
         http = _make_requests_session(
-            [_make_response(content=rsp_pb.SerializeToString())]
+            [_make_response(content=rsp_pb._pb.SerializeToString())]
         )
         client_info = _make_client_info()
         client = mock.Mock(
@@ -761,7 +761,7 @@ class TestHTTPDatastoreAPI(unittest.TestCase):
         response = ds_api.allocate_ids(project, [])
 
         # Check the result and verify the callers.
-        self.assertEqual(response, rsp_pb)
+        self.assertEqual(response, rsp_pb._pb)
         self.assertEqual(list(response.keys), [])
 
         uri = _build_expected_url(client._base_url, project, "allocateIds")
@@ -769,7 +769,7 @@ class TestHTTPDatastoreAPI(unittest.TestCase):
         self.assertEqual(list(request.keys), [])
 
     def test_allocate_ids_non_empty(self):
-        from google.cloud.datastore_v1.proto import datastore_pb2
+        from google.cloud.datastore_v1.types import datastore as datastore_pb2
 
         project = "PROJECT"
         before_key_pbs = [
@@ -778,12 +778,12 @@ class TestHTTPDatastoreAPI(unittest.TestCase):
         ]
         after_key_pbs = [_make_key_pb(project), _make_key_pb(project, id_=2345)]
         rsp_pb = datastore_pb2.AllocateIdsResponse()
-        rsp_pb.keys.add().CopyFrom(after_key_pbs[0])
-        rsp_pb.keys.add().CopyFrom(after_key_pbs[1])
+        rsp_pb._pb.keys.add().CopyFrom(after_key_pbs[0]._pb)
+        rsp_pb._pb.keys.add().CopyFrom(after_key_pbs[1]._pb)
 
         # Create mock HTTP and client with response.
         http = _make_requests_session(
-            [_make_response(content=rsp_pb.SerializeToString())]
+            [_make_response(content=rsp_pb._pb.SerializeToString())]
         )
         client_info = _make_client_info()
         client = mock.Mock(
@@ -798,8 +798,8 @@ class TestHTTPDatastoreAPI(unittest.TestCase):
         response = ds_api.allocate_ids(project, before_key_pbs)
 
         # Check the result and verify the callers.
-        self.assertEqual(list(response.keys), after_key_pbs)
-        self.assertEqual(response, rsp_pb)
+        self.assertEqual(list(response.keys), [i._pb for i in after_key_pbs])
+        self.assertEqual(response, rsp_pb._pb)
 
         uri = _build_expected_url(client._base_url, project, "allocateIds")
         request = _verify_protobuf_call(http, uri, datastore_pb2.AllocateIdsRequest())
@@ -863,5 +863,5 @@ def _verify_protobuf_call(http, expected_url, pb):
     )
 
     data = http.request.mock_calls[0][2]["data"]
-    pb.ParseFromString(data)
+    pb._pb.ParseFromString(data)
     return pb
